package HeatLibExercise "1-dimensional heat flow" 
  import Modelica.SIunits;
  extends Modelica.Icons.Library;
  
  package Interfaces "Connectors and partial models for 1D heat flow" 
    extends Modelica.Icons.Library;
    
    connector Surface_a "1D Heat flow connector (filled icon)" 
      SIunits.Temperature T "Absolute temperature";
      flow SIunits.HeatFlux q "Heat flowing into element";
      
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100], 
          grid=[2, 2], 
          component=[20, 20]), 
        Window(
          x=0.23, 
          y=0.02, 
          width=0.56, 
          height=0.68), 
        Icon(Rectangle(extent=[-100, -100; 100, 100], style(color=41, 
                fillColor=41))), 
        Diagram(Rectangle(extent=[-100, -100; 100, 100], style(color=41, 
                fillColor=41)), Text(
            extent=[-100, -120; 100, -220], 
            string="%name", 
            style(color=0))));
    end Surface_a;
    connector Surface_b "1D Heat flow connector (non-filled icon)" 
      SIunits.Temperature T "Absolute temperature";
      flow SIunits.HeatFlux q "Heat flowing into element";
      
      annotation (
        Coordsys(
          extent=[-100, -100; 100, 100], 
          grid=[2, 2], 
          component=[20, 20]), 
        Window(
          x=0.23, 
          y=0.02, 
          width=0.56, 
          height=0.68), 
        Icon(Rectangle(extent=[-100, -100; 100, 100], style(color=41, 
                fillColor=7))), 
        Diagram(Rectangle(extent=[-100, -100; 100, 100], style(color=41, 
                fillColor=7)), Text(
            extent=[-100, -120; 100, -220], 
            string="%name", 
            style(color=0))));
    end Surface_b;
    
    annotation (Coordsys(
        extent=[0, 0; 188, 115], 
        grid=[1, 1], 
        component=[20, 20]), Window(
        x=0.05, 
        y=0.04, 
        width=0.19, 
        height=0.21, 
        library=1, 
        autolayout=1));
  end Interfaces;
  model TempSource_C "Celsius temperature source" 
    Interfaces.Surface_b surface_b annotation (extent=[90, -10; 110, 10]);
    annotation (
      Coordsys(
        extent=[-100, -100; 100, 100], 
        grid=[2, 2], 
        component=[20, 20]), 
      Window(
        x=0.21, 
        y=0.11, 
        width=0.6, 
        height=0.57), 
      Icon(
        Rectangle(extent=[-40, 100; 20, -60], style(color=0)), 
        Line(points=[-100, 0; -40, 0]), 
        Rectangle(extent=[20, 10; 90, -10], style(
            color=1, 
            fillColor=1, 
            fillPattern=1)), 
        Rectangle(extent=[-40, 88; -12, 78], style(
            color=8, 
            fillColor=9, 
            fillPattern=1)), 
        Rectangle(extent=[-40, 58; -12, 48], style(
            color=8, 
            fillColor=9, 
            fillPattern=1)), 
        Rectangle(extent=[-40, 30; -12, 20], style(
            color=8, 
            fillColor=9, 
            fillPattern=1)), 
        Rectangle(extent=[-40, 0; -12, -10], style(
            color=8, 
            fillColor=9, 
            fillPattern=1)), 
        Rectangle(extent=[-40, -30; -12, -40], style(
            color=8, 
            fillColor=9, 
            fillPattern=1)), 
        Text(
          extent=[-100, 60; -100, 30], 
          string="T", 
          style(color=0)), 
        Text(extent=[0, -76; 0, -136], string="%name"), 
        Text(
          extent=[-100, -30; -100, -60], 
          string="[degC]", 
          style(color=0))));
    Modelica.Blocks.Interfaces.InPort inPort(final n=1) annotation (extent=[-
          120, -10; -100, 10]);
  equation 
    surface_b.T = inPort.signal[1] - Modelica.Constants.T_zero;
  end TempSource_C;
  model HeatResistance "Ideal heat flow without storage of energy" 
    parameter SIunits.Area A(min=0) "area of heat resistance";
    parameter SIunits.Length L(min=Modelica.Constants.eps) 
      "length of heat resistance";
    parameter SIunits.ThermalConductivity lambda(min=0) 
      "thermal conductivity of material";
    annotation (
      Coordsys(
        extent=[-100, -100; 100, 100], 
        grid=[1, 1], 
        component=[20, 20]), 
      Window(
        x=0.13, 
        y=0.02, 
        width=0.63, 
        height=0.7), 
      Icon(Rectangle(extent=[-90, 20; 90, -20], style(
            gradient=2, 
            fillColor=1, 
            fillPattern=1)), Text(extent=[0, 91; 0, 31], string="%name")), 
      Diagram(Polygon(points=[-81, 10; -78, 10; 40, 10; 40, 30; 80, 0; 40, -30
              ; 40, -10; -80, -10; -80, 10; -81, 10], style(color=41, fillColor
              =41))));
    Interfaces.Surface_a surface_a annotation (extent=[-110, -10; -90, 10]);
    Interfaces.Surface_b surface_b annotation (extent=[90, -10; 110, 10]);
  equation 
    surface_a.q = lambda*A/L*(surface_a.T - surface_b.T);
    surface_b.q = -surface_a.q;
  end HeatResistance;
  model HeatCapacitance "Ideal heat storage in a block without heat flow" 
    parameter SIunits.Mass m(min=0) "mass of block";
    parameter SIunits.SpecificHeatCapacity c(min=0) 
      "specifc heat capacity of block";
    parameter SIunits.Temp_C T0=20 "initial temperature of block";
    annotation (
      Coordsys(
        extent=[-100, -100; 100, 100], 
        grid=[1, 1], 
        component=[20, 20]), 
      Window(
        x=0.13, 
        y=0.06, 
        width=0.63, 
        height=0.63), 
      Icon(Rectangle(extent=[-100, -10; 100, -80], style(
            color=1, 
            gradient=3, 
            fillColor=1, 
            fillPattern=1)), Text(extent=[0, -89; 0, -149], string="%name")));
    Interfaces.Surface_a surface_a(T(final start=T0 - Modelica.Constants.
            T_zero)) annotation (extent=[-10, -10; 10, 10]);
  equation 
    surface_a.q = c*m*der(surface_a.T);
  end HeatCapacitance;
  annotation (Coordsys(
      extent=[0, 0; 442, 394], 
      grid=[1, 1], 
      component=[20, 20]), Window(
      x=0.45, 
      y=0.01, 
      width=0.44, 
      height=0.65, 
      library=1, 
      autolayout=1));
end HeatLibExercise;
